==> zego_uikit-0.0.2.tar.gz: lib/src/components/audio_video/toggle_camera_button.dart <==
// Dart imports:
import 'dart:math' as math;

// Flutter imports:
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';

// Package imports:
import 'package:flutter_screenutil/flutter_screenutil.dart';

// Project imports:
import 'package:zego_uikit/src/components/defines.dart';
import 'package:zego_uikit/src/components/internal/internal.dart';
import 'package:zego_uikit/src/service/zego_uikit.dart';

/// button used to open/close camera
class ZegoToggleCameraButton extends StatefulWidget {
  const ZegoToggleCameraButton({
    Key? key,
    this.normalIcon,
    this.checkedIcon,
    this.afterClicked,
    this.defaultOn = true,
    this.iconSize,
    this.buttonSize,
  }) : super(key: key);

  final ButtonIcon? normalIcon;
  final ButtonIcon? checkedIcon;

  ///  You can do what you want after clicked.
  final ButtonClickBoolCallback? afterClicked;

  /// whether to open camera by default
  final bool defaultOn;

  /// the size of button's icon
  final Size? iconSize;

  /// the size of button
  final Size? buttonSize;

  @override
  State<ZegoToggleCameraButton> createState() => _ZegoToggleCameraButtonState();
}

class _ZegoToggleCameraButtonState extends State<ZegoToggleCameraButton> {
  @override
  void initState() {
    super.initState();

    SchedulerBinding.instance?.addPostFrameCallback((_) {
      /// synchronizing the default status
      ZegoUIKit().turnCameraOn(widget.defaultOn);
    });
  }

  @override
  Widget build(BuildContext context) {
    Size containerSize = widget.buttonSize ?? Size(96.r, 96.r);
    Size sizeBoxSize = widget.iconSize ?? Size(56.r, 56.r);

    /// listen local camera state changes
    return ValueListenableBuilder<bool>(
      valueListenable:
          ZegoUIKit().getCameraStateNotifier(ZegoUIKit().getLocalUser().id),
      builder: (context, isCameraOn, _) {
        /// update if camera state changed
        return GestureDetector(
          onTap: onPressed,
          child: Container(
            width: containerSize.width,
            height: containerSize.height,
            decoration: BoxDecoration(
              color: isCameraOn
                  ? widget.checkedIcon?.backgroundColor ??
                      controlBarButtonCheckedBackgroundColor
                  : widget.normalIcon?.backgroundColor ??
                      controlBarButtonBackgroundColor,
              borderRadius: BorderRadius.all(Radius.circular(
                  math.min(containerSize.width, containerSize.height) / 2)),
            ),
            child: SizedBox.fromSize(
              size: sizeBoxSize,
              child: isCameraOn
                  ? widget.normalIcon?.icon ??
                      UIKitImage.asset(
                          StyleIconUrls.iconS1ControlBarCameraNormal)
                  : widget.checkedIcon?.icon ??
                      UIKitImage.asset(StyleIconUrls.iconS1ControlBarCameraOff),
            ),
          ),
        );
      },
    );
  }

  void onPressed() {
    /// get current camera state
    var valueNotifier =
        ZegoUIKit().getCameraStateNotifier(ZegoUIKit().getLocalUser().id);

    var targetState = !valueNotifier.value;

    /// reverse current state
    ZegoUIKit().turnCameraOn(targetState);

    if (widget.afterClicked != null) {
      widget.afterClicked!(targetState);
    }
  }
}

==> zego_uikit-1.3.0.tar.gz: lib/src/components/audio_video/toggle_camera_button.dart <==
// Dart imports:
import 'dart:math' as math;

// Flutter imports:
import 'package:flutter/material.dart';
import 'package:flutter/scheduler.dart';

// Package imports:
import 'package:flutter_screenutil/flutter_screenutil.dart';

// Project imports:
import 'package:zego_uikit/src/components/defines.dart';
import 'package:zego_uikit/src/components/internal/internal.dart';
import 'package:zego_uikit/src/services/services.dart';

/// button used to open/close camera
class ZegoToggleCameraButton extends StatefulWidget {
  const ZegoToggleCameraButton({
    Key? key,
    this.normalIcon,
    this.checkedIcon,
    this.afterClicked,
    this.defaultOn = true,
    this.iconSize,
    this.buttonSize,
  }) : super(key: key);

  final ButtonIcon? normalIcon;
  final ButtonIcon? checkedIcon;

  ///  You can do what you want after clicked.
  final ButtonClickBoolCallback? afterClicked;

  /// whether to open camera by default
  final bool defaultOn;

  /// the size of button's icon
  final Size? iconSize;

  /// the size of button
  final Size? buttonSize;

  @override
  State<ZegoToggleCameraButton> createState() => _ZegoToggleCameraButtonState();
}

class _ZegoToggleCameraButtonState extends State<ZegoToggleCameraButton> {
  @override
  void initState() {
    super.initState();

    SchedulerBinding.instance?.addPostFrameCallback((_) {
      /// synchronizing the default status
      ZegoUIKit().turnCameraOn(widget.defaultOn);
    });
  }

  @override
  Widget build(BuildContext context) {
    Size containerSize = widget.buttonSize ?? Size(96.r, 96.r);
    Size sizeBoxSize = widget.iconSize ?? Size(56.r, 56.r);

    /// listen local camera state changes
    return ValueListenableBuilder<bool>(
      valueListenable:
          ZegoUIKit().getCameraStateNotifier(ZegoUIKit().getLocalUser().id),
      builder: (context, isCameraOn, _) {
        /// update if camera state changed
        return GestureDetector(
          onTap: onPressed,
          child: Container(
            width: containerSize.width,
            height: containerSize.height,
            decoration: BoxDecoration(
              color: isCameraOn
                  ? widget.checkedIcon?.backgroundColor ??
                      controlBarButtonCheckedBackgroundColor
                  : widget.normalIcon?.backgroundColor ??
                      controlBarButtonBackgroundColor,
              borderRadius: BorderRadius.all(Radius.circular(
                  math.min(containerSize.width, containerSize.height) / 2)),
            ),
            child: SizedBox.fromSize(
              size: sizeBoxSize,
              child: isCameraOn
                  ? widget.normalIcon?.icon ??
                      UIKitImage.asset(
                          StyleIconUrls.iconS1ControlBarCameraNormal)
                  : widget.checkedIcon?.icon ??
                      UIKitImage.asset(StyleIconUrls.iconS1ControlBarCameraOff),
            ),
          ),
        );
      },
    );
  }

  void onPressed() {
    /// get current camera state
    var valueNotifier =
        ZegoUIKit().getCameraStateNotifier(ZegoUIKit().getLocalUser().id);

    var targetState = !valueNotifier.value;

    /// reverse current state
    ZegoUIKit().turnCameraOn(targetState);

    if (widget.afterClicked != null) {
      widget.afterClicked!(targetState);
    }
  }
}
